open

Function open 

pub fn open(url: &str) -> Result<()>
Opens an https:// URL in the user’s browser, on the machine the viewer runs on (a new tab in a browser viewer). Only as a direct result of user input: while handling a key, paste, pointer press or command, or within a second after one, and once per input; Error::Invalid otherwise or for a URL that is not plain https, Error::GrantDenied { grant: "url.open:<host>" } for a host no grant names.