instance_id

Function instance_id 

pub fn instance_id() -> String
This viewer instance: shared by every plugin of one running viewer, different in every other viewer and after a restart. A key such as <plugin>.seen.<instance> is this viewer’s own.