pub struct Child {
pub pid: u32,
}Expand description
A spawned program.
Fields
pid: u32Implementations
Sourceimpl Child
impl Child
Sourcepub fn wait(self) -> Result<i32>
pub fn wait(self) -> Result<i32>
Blocks the plugin until the program exits; its exit status (a
signal is negated). Prefer awaiting
Event::ProcessExited.
Sourcepub fn wait_timeout(self, timeout: Duration) -> Result<Option<i32>>
pub fn wait_timeout(self, timeout: Duration) -> Result<Option<i32>>
Blocks the plugin until the program exits or timeout passes:
its exit status, or none when it still runs (kill it then).
Sourcepub fn close_stdin(self) -> Result<()>
pub fn close_stdin(self) -> Result<()>
Closes a piped stdin: the program reads end of file.