Command

Struct Command 

pub struct Command {
    pub program: String,
    pub args: Vec<String>,
    pub env: Vec<(String, String)>,
    pub env_remove: Vec<String>,
    pub clear_env: bool,
    pub cwd: Option<String>,
    pub stdin: Stdio,
    pub stdout: Stdio,
    pub stderr: Stdio,
}
A program with its arguments, environment, directory and streams. It inherits the plugin’s environment (env) and runs in the user’s home unless told otherwise.

Fields

program: Stringargs: Vec<String>env: Vec<(String, String)>

Variables set on top of the plugin’s environment (env).

env_remove: Vec<String>

Variables removed from the plugin’s environment first.

clear_env: bool

Start from an empty environment: only Command::env.

cwd: Option<String>

The working directory; the user’s home when None.

stdin: Stdiostdout: Stdiostderr: Stdio

Implementations

Source

impl Command

pub fn new(program: &str) -> Self

program with no stdin and its output in the daemon’s log.

pub fn arg(self, arg: &str) -> Self

pub fn args(self, args: &[&str]) -> Self

pub fn env(self, key: &str, value: &str) -> Self

pub fn env_remove(self, key: &str) -> Self

Removes key from the inherited environment (GIT_DIR, say).

pub fn clear_env(self) -> Self

pub fn cwd(self, cwd: &str) -> Self

pub fn stdin(self, stdin: Stdio) -> Self

pub fn stdout(self, stdout: Stdio) -> Self

pub fn stderr(self, stderr: Stdio) -> Self

pub fn spawn(&self) -> Result<Child>