pub struct Caller {
pub machine_id: String,
pub plugin_id: String,
pub kind: String,
pub epoch: Option<u64>,
pub controller_machine_id: Option<String>,
pub controller_fencing_token: Option<String>,
}Expand description
Who made a call, as the account routed it.
Fields
machine_id: StringThe machine the calling runtime runs on.
plugin_id: Stringkind: Stringui or daemon.
epoch: Option<u64>The caller’s lease epoch, when a singleton daemon called.
controller_machine_id: Option<String>The account controller lease when the call was made: the machine the user controls from and its fencing token.
controller_fencing_token: Option<String>Implementations