Event

Enum Event 

#[non_exhaustive]
pub enum Event {
Show 22 variants Resize { surface: String, geometry: Geometry, }, Visibility { surface: String, visible: bool, }, CapabilitiesChanged, Driving(bool), ValueChanged { key: String, value: Option<Json>, }, Live { key: String, payload: Json, }, LiveDeleted { key: String, }, Plugin { name: String, payload: Json, }, AccountChanged, Key(Key), Paste { surface: String, text: String, }, Pointer(Pointer), ThemeChanged, Focus { surface: String, focused: bool, }, Command(String), CallResult { id: CallId, result: Result<Json>, }, FileChanged { watch: u32, paths: Vec<String>, }, WatchFailed { watch: u32, error: String, }, ProcessOutput { pid: u32, stderr: bool, bytes: Vec<u8>, }, ProcessExited { pid: u32, status: i32, }, PaneChanged { kind: PaneChangeKind, pane: Pane, }, Interest(Interest),
}
What the host tells a plugin besides frames.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Resize

A surface changed size. The SDK has rebound it; repaint it.

Fields

surface: String
geometry: Geometry


Visibility

A surface became visible or hidden.

Fields

surface: String
visible: bool


CapabilitiesChanged

Graphics support, cell pixel size or frame rate changed (capabilities).



Driving(bool)



ValueChanged

A watched value changed (crate::values::Values::watch).

Fields

value: Option<Json>


Live

A live message (crate::live::Live::subscribe).

Fields

payload: Json


LiveDeleted

A live key was withdrawn (crate::live::Live::delete).

Fields



Plugin

A plugin event (crate::events::Events::on).

Fields

name: String
payload: Json


AccountChanged

The account changed (crate::account::watch).



Key(Key)

A key on the surface with input focus.



Paste

Text pasted into the surface with input focus.

Fields

surface: String
text: String


Pointer(Pointer)

The pointer over one of the plugin’s surfaces.



ThemeChanged

The viewer’s theme changed (crate::view::theme).



Focus

A surface gained or lost input focus.

Fields

surface: String
focused: bool


Command(String)

The user ran one of the manifest’s commands, by id.



CallResult

A Calls::call_async finished: the companion’s answer, or why there is none (a timeout is Error::Unavailable).

Fields

result: Result<Json>


FileChanged

Daemon plugins: files under a watch changed; every path that changed since the last delivery.

Fields

watch: u32
paths: Vec<String>


WatchFailed

Daemon plugins: a watch stopped delivering (the watcher’s error).

Fields

watch: u32
error: String


ProcessOutput

Daemon plugins: output from a child’s piped stream.

Fields

pid: u32
stderr: bool
bytes: Vec<u8>


ProcessExited

Daemon plugins: a child exited (a signal is negated), after the last of its output.

Fields

pid: u32
status: i32


PaneChanged

Daemon plugins: a pane on the daemon’s machine changed (panes::subscribe).

Fields

pane: Pane


Interest(Interest)

Daemon plugins: which of the plugin’s UI surfaces the account’s viewers show changed (Context::interest). Start reading an outside source when any turns true and stop when it turns false.